diff --git a/.travis.yml b/.travis.yml
index 65c9dc69e..911042262 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -11,7 +11,7 @@ install:
   - GLIDE_DOWNLOAD="https://github.com/Masterminds/glide/releases/download/$GLIDE_TAG/glide-$GLIDE_TAG-linux-amd64.tar.gz"
   - curl -L $GLIDE_DOWNLOAD | tar -xvz
   - export PATH=$PATH:$PWD/linux-amd64/
-  - BTCD_VERSION=$(cat glide.yaml | grep -A1 btcd | tail -n1 | awk '{ print $2}')
+  - BTCD_VERSION=$(cat Gopkg.toml | grep -A1 btcd | tail -n1 | awk '{ print $3 }' | tr -d '"')
   - mkdir -p $GOPATH/src/github.com/roasbeef/
   - pushd $GOPATH/src/github.com/roasbeef/
   - git clone https://github.com/roasbeef/btcd
diff --git a/Gopkg.lock b/Gopkg.lock
new file mode 100644
index 000000000..2bae08813
--- /dev/null
+++ b/Gopkg.lock
@@ -0,0 +1,364 @@
+# This file is autogenerated, do not edit; changes may be undone by the next 'dep ensure'.
+
+
+[[projects]]
+  branch = "master"
+  name = "git.schwanenlied.me/yawning/bsaes.git"
+  packages = [
+    "ct32",
+    "ct64",
+    "ghash",
+    "internal/modes"
+  ]
+  revision = "e06297f34865a50b8e473105e52cb64ad1b55da8"
+
+[[projects]]
+  name = "github.com/Yawning/aez"
+  packages = ["."]
+  revision = "4dad034d9db2caec23fb8f69b9160ae16f8d46a3"
+
+[[projects]]
+  branch = "master"
+  name = "github.com/aead/chacha20"
+  packages = [
+    ".",
+    "chacha"
+  ]
+  revision = "c8d29375923a8e1d2a0f0dc0fc1d8a0aba5b97ba"
+
+[[projects]]
+  branch = "master"
+  name = "github.com/aead/siphash"
+  packages = ["."]
+  revision = "e404fcfc888570cadd1610538e2dbc89f66af814"
+
+[[projects]]
+  name = "github.com/awalterschulze/gographviz"
+  packages = [
+    ".",
+    "ast",
+    "parser",
+    "scanner",
+    "token"
+  ]
+  revision = "761fd5fbb34e4c2c138c280395b65b48e4ff5a53"
+
+[[projects]]
+  name = "github.com/btcsuite/btclog"
+  packages = ["."]
+  revision = "84c8d2346e9fc8c7b947e243b9c24e6df9fd206a"
+
+[[projects]]
+  branch = "master"
+  name = "github.com/btcsuite/fastsha256"
+  packages = ["."]
+  revision = "637e656429416087660c84436a2a035d69d54e2e"
+
+[[projects]]
+  branch = "master"
+  name = "github.com/btcsuite/go-socks"
+  packages = ["socks"]
+  revision = "4720035b7bfd2a9bb130b1c184f8bbe41b6f0d0f"
+
+[[projects]]
+  branch = "master"
+  name = "github.com/btcsuite/golangcrypto"
+  packages = [
+    "nacl/secretbox",
+    "pbkdf2",
+    "poly1305",
+    "ripemd160",
+    "salsa20/salsa",
+    "scrypt",
+    "ssh/terminal"
+  ]
+  revision = "53f62d9b43e87a6c56975cf862af7edf33a8d0df"
+
+[[projects]]
+  branch = "master"
+  name = "github.com/btcsuite/websocket"
+  packages = ["."]
+  revision = "31079b6807923eb23992c421b114992b95131b55"
+
+[[projects]]
+  name = "github.com/coreos/bbolt"
+  packages = ["."]
+  revision = "4f5275f4ebbf6fe7cb772de987fa96ee674460a7"
+
+[[projects]]
+  name = "github.com/davecgh/go-spew"
+  packages = ["spew"]
+  revision = "8991bc29aa16c548c550c7ff78260e27b9ab7c73"
+
+[[projects]]
+  name = "github.com/go-errors/errors"
+  packages = ["."]
+  revision = "a6af135bd4e28680facf08a3d206b454abc877a4"
+
+[[projects]]
+  name = "github.com/golang/protobuf"
+  packages = [
+    "jsonpb",
+    "proto",
+    "protoc-gen-go/descriptor",
+    "ptypes/any",
+    "ptypes/struct"
+  ]
+  revision = "bbd03ef6da3a115852eaf24c8a1c46aeb39aa175"
+
+[[projects]]
+  name = "github.com/grpc-ecosystem/grpc-gateway"
+  packages = [
+    "runtime",
+    "runtime/internal",
+    "utilities"
+  ]
+  revision = "f2862b476edcef83412c7af8687c9cd8e4097c0f"
+
+[[projects]]
+  name = "github.com/jessevdk/go-flags"
+  packages = ["."]
+  revision = "f88afde2fa19a30cf50ba4b05b3d13bc6bae3079"
+
+[[projects]]
+  name = "github.com/jrick/logrotate"
+  packages = ["rotator"]
+  revision = "a93b200c26cbae3bb09dd0dc2c7c7fe1468a034a"
+
+[[projects]]
+  branch = "master"
+  name = "github.com/juju/loggo"
+  packages = ["."]
+  revision = "8232ab8918d91c72af1a9fb94d3edbe31d88b790"
+
+[[projects]]
+  name = "github.com/kkdai/bstream"
+  packages = ["."]
+  revision = "f391b8402d23024e7c0f624b31267a89998fca95"
+
+[[projects]]
+  branch = "master"
+  name = "github.com/lightninglabs/gozmq"
+  packages = ["."]
+  revision = "0d266ba6d55ea65c18c7a02d8992c89355149e80"
+
+[[projects]]
+  name = "github.com/lightninglabs/neutrino"
+  packages = [
+    ".",
+    "filterdb",
+    "headerfs"
+  ]
+  revision = "601b7eda6e5c9e8ca91c097f0bb7be2664802ab3"
+
+[[projects]]
+  name = "github.com/lightningnetwork/lightning-onion"
+  packages = ["."]
+  revision = "6d4b1353e2835def84ee240f40499464521c6046"
+
+[[projects]]
+  name = "github.com/ltcsuite/ltcd"
+  packages = [
+    "btcjson",
+    "chaincfg",
+    "chaincfg/chainhash",
+    "wire"
+  ]
+  revision = "5f654d5faab99ee2b3488fabba98e5f7a5257ee3"
+
+[[projects]]
+  name = "github.com/miekg/dns"
+  packages = [
+    ".",
+    "internal/socket"
+  ]
+  revision = "79bfde677fa81ff8d27c4330c35bda075d360641"
+
+[[projects]]
+  name = "github.com/roasbeef/btcd"
+  packages = [
+    "addrmgr",
+    "blockchain",
+    "btcec",
+    "btcjson",
+    "chaincfg",
+    "chaincfg/chainhash",
+    "connmgr",
+    "database",
+    "integration/rpctest",
+    "peer",
+    "rpcclient",
+    "txscript",
+    "wire"
+  ]
+  revision = "e6807bc4dd5ddbb95b4ab163f6dd61e4ad79463a"
+
+[[projects]]
+  name = "github.com/roasbeef/btcutil"
+  packages = [
+    ".",
+    "base58",
+    "bech32",
+    "gcs",
+    "gcs/builder",
+    "hdkeychain",
+    "txsort"
+  ]
+  revision = "c3ff179366044979fb9856c2feb79bd4c2184c7a"
+
+[[projects]]
+  name = "github.com/roasbeef/btcwallet"
+  packages = [
+    "chain",
+    "internal/helpers",
+    "internal/legacy/keystore",
+    "internal/legacy/rename",
+    "internal/prompt",
+    "internal/zero",
+    "snacl",
+    "waddrmgr",
+    "wallet",
+    "wallet/internal/txsizes",
+    "wallet/txauthor",
+    "wallet/txrules",
+    "walletdb",
+    "walletdb/bdb",
+    "wtxmgr"
+  ]
+  revision = "46f7390abe89576059b52588d91b82212e753493"
+
+[[projects]]
+  branch = "master"
+  name = "github.com/rogpeppe/fastuuid"
+  packages = ["."]
+  revision = "6724a57986aff9bff1a1770e9347036def7c89f6"
+
+[[projects]]
+  name = "github.com/tv42/zbase32"
+  packages = ["."]
+  revision = "501572607d0273fc75b3b261fa4904d63f6ffa0e"
+
+[[projects]]
+  name = "github.com/urfave/cli"
+  packages = ["."]
+  revision = "1efa31f08b9333f1bd4882d61f9d668a70cd902e"
+
+[[projects]]
+  name = "golang.org/x/crypto"
+  packages = [
+    "blake2b",
+    "chacha20poly1305",
+    "curve25519",
+    "hkdf",
+    "internal/chacha20",
+    "nacl/box",
+    "nacl/secretbox",
+    "pbkdf2",
+    "poly1305",
+    "ripemd160",
+    "salsa20",
+    "salsa20/salsa",
+    "scrypt",
+    "ssh/terminal"
+  ]
+  revision = "49796115aa4b964c318aad4f3084fdb41e9aa067"
+
+[[projects]]
+  name = "golang.org/x/net"
+  packages = [
+    "context",
+    "http2",
+    "http2/hpack",
+    "idna",
+    "internal/timeseries",
+    "lex/httplex",
+    "proxy",
+    "trace"
+  ]
+  revision = "ae89d30ce0c63142b652837da33d782e2b0a9b25"
+
+[[projects]]
+  branch = "master"
+  name = "golang.org/x/sys"
+  packages = [
+    "unix",
+    "windows"
+  ]
+  revision = "c28acc882ebcbfbe8ce9f0f14b9ac26ee138dd51"
+
+[[projects]]
+  name = "golang.org/x/text"
+  packages = [
+    "collate",
+    "collate/build",
+    "internal/colltab",
+    "internal/gen",
+    "internal/tag",
+    "internal/triegen",
+    "internal/ucd",
+    "language",
+    "secure/bidirule",
+    "transform",
+    "unicode/bidi",
+    "unicode/cldr",
+    "unicode/norm",
+    "unicode/rangetable"
+  ]
+  revision = "f21a4dfb5e38f5895301dc265a8def02365cc3d0"
+  version = "v0.3.0"
+
+[[projects]]
+  name = "google.golang.org/genproto"
+  packages = [
+    "googleapis/api/annotations",
+    "googleapis/rpc/status"
+  ]
+  revision = "df60624c1e9b9d2973e889c7a1cff73155da81c4"
+
+[[projects]]
+  name = "google.golang.org/grpc"
+  packages = [
+    ".",
+    "codes",
+    "connectivity",
+    "credentials",
+    "grpclb/grpc_lb_v1",
+    "grpclog",
+    "internal",
+    "keepalive",
+    "metadata",
+    "naming",
+    "peer",
+    "stats",
+    "status",
+    "tap",
+    "transport"
+  ]
+  revision = "b3ddf786825de56a4178401b7e174ee332173b66"
+
+[[projects]]
+  branch = "v1"
+  name = "gopkg.in/errgo.v1"
+  packages = ["."]
+  revision = "442357a80af5c6bf9b6d51ae791a39c3421004f3"
+
+[[projects]]
+  name = "gopkg.in/macaroon-bakery.v2"
+  packages = [
+    "bakery",
+    "bakery/checkers",
+    "bakery/internal/macaroonpb"
+  ]
+  revision = "94012773d2874a067572bd16d7d11ae02968b47b"
+
+[[projects]]
+  name = "gopkg.in/macaroon.v2"
+  packages = ["."]
+  revision = "bed2a428da6e56d950bed5b41fcbae3141e5b0d0"
+
+[solve-meta]
+  analyzer-name = "dep"
+  analyzer-version = 1
+  inputs-digest = "bc62d68c801d1d76b0d443fe409f6370d3141db3d62d0875f29531955efc8c72"
+  solver-name = "gps-cdcl"
+  solver-version = 1
diff --git a/Gopkg.toml b/Gopkg.toml
new file mode 100644
index 000000000..4b847f3df
--- /dev/null
+++ b/Gopkg.toml
@@ -0,0 +1,107 @@
+[[constraint]]
+  name = "github.com/awalterschulze/gographviz"
+  revision = "761fd5fbb34e4c2c138c280395b65b48e4ff5a53"
+
+[[constraint]]
+  name = "github.com/btcsuite/btclog"
+  revision = "84c8d2346e9fc8c7b947e243b9c24e6df9fd206a"
+
+[[constraint]]
+  name = "github.com/coreos/bbolt"
+  revision = "4f5275f4ebbf6fe7cb772de987fa96ee674460a7"
+
+[[constraint]]
+  name = "github.com/davecgh/go-spew"
+  revision = "8991bc29aa16c548c550c7ff78260e27b9ab7c73"
+
+[[constraint]]
+  name = "github.com/go-errors/errors"
+  revision = "a6af135bd4e28680facf08a3d206b454abc877a4"
+
+[[constraint]]
+  name = "github.com/golang/protobuf"
+  revision = "bbd03ef6da3a115852eaf24c8a1c46aeb39aa175"
+
+[[constraint]]
+  name = "github.com/grpc-ecosystem/grpc-gateway"
+  revision = "f2862b476edcef83412c7af8687c9cd8e4097c0f"
+
+[[constraint]]
+  name = "github.com/jessevdk/go-flags"
+  revision = "f88afde2fa19a30cf50ba4b05b3d13bc6bae3079"
+
+[[constraint]]
+  name = "github.com/jrick/logrotate"
+  revision = "a93b200c26cbae3bb09dd0dc2c7c7fe1468a034a"
+
+[[constraint]]
+  name = "github.com/kkdai/bstream"
+  revision = "f391b8402d23024e7c0f624b31267a89998fca95"
+
+[[constraint]]
+  name = "github.com/lightninglabs/neutrino"
+  revision = "601b7eda6e5c9e8ca91c097f0bb7be2664802ab3"
+
+[[constraint]]
+  name = "github.com/lightningnetwork/lightning-onion"
+  revision = "6d4b1353e2835def84ee240f40499464521c6046"
+
+[[constraint]]
+  name = "github.com/ltcsuite/ltcd"
+  revision = "5f654d5faab99ee2b3488fabba98e5f7a5257ee3"
+
+[[constraint]]
+  name = "github.com/miekg/dns"
+  revision = "79bfde677fa81ff8d27c4330c35bda075d360641"
+
+[[constraint]]
+  name = "github.com/roasbeef/btcutil"
+  revision = "c3ff179366044979fb9856c2feb79bd4c2184c7a"
+
+[[constraint]]
+  name = "github.com/roasbeef/btcd"
+  revision = "e6807bc4dd5ddbb95b4ab163f6dd61e4ad79463a"
+
+[[constraint]]
+  name = "github.com/roasbeef/btcwallet"
+  revision = "46f7390abe89576059b52588d91b82212e753493"
+
+[[constraint]]
+  name = "github.com/tv42/zbase32"
+  revision = "501572607d0273fc75b3b261fa4904d63f6ffa0e"
+
+[[constraint]]
+  name = "github.com/urfave/cli"
+  revision = "1efa31f08b9333f1bd4882d61f9d668a70cd902e"
+
+[[constraint]]
+  name = "github.com/Yawning/aez"
+  revision = "4dad034d9db2caec23fb8f69b9160ae16f8d46a3"
+
+[[constraint]]
+  name = "golang.org/x/crypto"
+  revision = "49796115aa4b964c318aad4f3084fdb41e9aa067"
+
+[[constraint]]
+  name = "golang.org/x/net"
+  revision = "ae89d30ce0c63142b652837da33d782e2b0a9b25"
+
+[[constraint]]
+  name = "google.golang.org/genproto"
+  revision = "df60624c1e9b9d2973e889c7a1cff73155da81c4"
+
+[[constraint]]
+  name = "google.golang.org/grpc"
+  revision = "b3ddf786825de56a4178401b7e174ee332173b66"
+
+[[constraint]]
+  name = "gopkg.in/macaroon-bakery.v2"
+  revision = "94012773d2874a067572bd16d7d11ae02968b47b"
+
+[[constraint]]
+  name = "gopkg.in/macaroon.v2"
+  revision = "bed2a428da6e56d950bed5b41fcbae3141e5b0d0"
+
+[prune]
+  go-tests = true
+  unused-packages = true
diff --git a/docker/lnd/Dockerfile b/docker/lnd/Dockerfile
index 6d67b5e2f..c7d42fe39 100644
--- a/docker/lnd/Dockerfile
+++ b/docker/lnd/Dockerfile
@@ -9,8 +9,8 @@ EXPOSE 9735 10009
 # queries required to connect to linked containers succeed.
 ENV GODEBUG netdns=cgo
 
-# Install glide to manage vendor.
-RUN go get -u github.com/Masterminds/glide
+# Install dep to manage vendor.
+RUN go get -u github.com/golang/dep/cmd/dep
 
 # Grab and install the latest version of lnd and all related dependencies.
 RUN git clone https://github.com/lightningnetwork/lnd $GOPATH/src/github.com/lightningnetwork/lnd
@@ -18,8 +18,8 @@ RUN git clone https://github.com/lightningnetwork/lnd $GOPATH/src/github.com/lig
 # Make lnd folder default.
 WORKDIR $GOPATH/src/github.com/lightningnetwork/lnd
 
-# Install dependency and install/build lnd.
-RUN glide install
+# Install dependencies and install/build lnd.
+RUN dep ensure
 RUN go install . ./cmd/...
 
 COPY "docker/lnd/start-lnd.sh" .
diff --git a/docs/INSTALL.md b/docs/INSTALL.md
index 83e3225d1..7e76319f7 100644
--- a/docs/INSTALL.md
+++ b/docs/INSTALL.md
@@ -41,11 +41,11 @@
     We recommend placing the above in your .bashrc or in a setup script so that
     you can avoid typing this every time you open a new terminal window.
 
-  * **Glide:** This project uses `Glide` to manage dependencies as well 
-    as to provide *reproducible builds*. To install `Glide`, execute the
+  * **dep:** This project uses `dep` to manage dependencies as well
+    as to provide *reproducible builds*. To install `dep`, execute the
     following command (assumes you already have Go properly installed):
     ```
-    go get -u github.com/Masterminds/glide
+    go get -u github.com/golang/dep/cmd/dep
     ```
 
 ### Installing lnd
@@ -55,17 +55,17 @@ related dependencies run the following commands:
 ```
 git clone https://github.com/lightningnetwork/lnd $GOPATH/src/github.com/lightningnetwork/lnd
 cd $GOPATH/src/github.com/lightningnetwork/lnd
-glide install
+dep ensure
 go install . ./cmd/...
 ```
 
 **Updating**
 
-To update your version of `lnd` to the latest version run the following 
+To update your version of `lnd` to the latest version run the following
 commands:
 ```
 cd $GOPATH/src/github.com/lightningnetwork/lnd
-git pull && glide install
+git pull && dep ensure
 go install . ./cmd/...
 ```
 
@@ -84,6 +84,7 @@ branch. To install, run the following commands:
 
 Install **btcd**: (must be from roasbeef fork, not from btcsuite)
 ```
+go get -u github.com/Masterminds/glide
 git clone https://github.com/roasbeef/btcd $GOPATH/src/github.com/roasbeef/btcd
 cd $GOPATH/src/github.com/roasbeef/btcd
 glide install
diff --git a/glide.lock b/glide.lock
deleted file mode 100644
index 5b35bb75a..000000000
--- a/glide.lock
+++ /dev/null
@@ -1,226 +0,0 @@
-hash: c214d062c3fd6f1fe3596c3a7bbe8f456308c7123c0868a5e13d21c9c223480a
-updated: 2018-03-10T18:59:00.939821514-08:00
-imports:
-- name: git.schwanenlied.me/yawning/bsaes.git
-  version: e06297f34865a50b8e473105e52cb64ad1b55da8
-  subpackages:
-  - ct32
-  - ct64
-  - ghash
-  - internal/modes
-- name: github.com/aead/chacha20
-  version: d31a916ded42d1640b9d89a26f8abd53cc96790c
-  subpackages:
-  - chacha
-- name: github.com/aead/siphash
-  version: e404fcfc888570cadd1610538e2dbc89f66af814
-- name: github.com/awalterschulze/gographviz
-  version: 9d8c9780eb4766351ae8489f78cb940cb6e0503d
-  subpackages:
-  - ast
-  - errors
-  - lexer
-  - parser
-  - token
-- name: github.com/btcsuite/btclog
-  version: 84c8d2346e9fc8c7b947e243b9c24e6df9fd206a
-- name: github.com/btcsuite/fastsha256
-  version: 637e656429416087660c84436a2a035d69d54e2e
-- name: github.com/btcsuite/go-socks
-  version: 4720035b7bfd2a9bb130b1c184f8bbe41b6f0d0f
-  subpackages:
-  - socks
-- name: github.com/btcsuite/golangcrypto
-  version: 53f62d9b43e87a6c56975cf862af7edf33a8d0df
-  subpackages:
-  - nacl/secretbox
-  - pbkdf2
-  - poly1305
-  - ripemd160
-  - salsa20/salsa
-  - scrypt
-  - ssh/terminal
-- name: github.com/btcsuite/websocket
-  version: 31079b6807923eb23992c421b114992b95131b55
-- name: github.com/coreos/bbolt
-  version: 4f5275f4ebbf6fe7cb772de987fa96ee674460a7
-- name: github.com/davecgh/go-spew
-  version: 346938d642f2ec3594ed81d874461961cd0faa76
-  subpackages:
-  - spew
-- name: github.com/go-errors/errors
-  version: 8fa88b06e5974e97fbf9899a7f86a344bfd1f105
-- name: github.com/golang/protobuf
-  version: ab9f9a6dab164b7d1246e0e688b0ab7b94d8553e
-  subpackages:
-  - jsonpb
-  - proto
-  - protoc-gen-go/descriptor
-  - ptypes/any
-  - ptypes/struct
-- name: github.com/grpc-ecosystem/grpc-gateway
-  version: f2862b476edcef83412c7af8687c9cd8e4097c0f
-  subpackages:
-  - runtime
-  - runtime/internal
-  - utilities
-- name: github.com/howeyc/gopass
-  version: bf9dde6d0d2c004a008c27aaee91170c786f6db8
-- name: github.com/jessevdk/go-flags
-  version: 1679536dcc895411a9f5848d9a0250be7856448c
-- name: github.com/jrick/logrotate
-  version: a93b200c26cbae3bb09dd0dc2c7c7fe1468a034a
-  subpackages:
-  - rotator
-- name: github.com/juju/loggo
-  version: 8232ab8918d91c72af1a9fb94d3edbe31d88b790
-- name: github.com/kkdai/bstream
-  version: f391b8402d23024e7c0f624b31267a89998fca95
-- name: github.com/lightninglabs/gozmq
-  version: 0d266ba6d55ea65c18c7a02d8992c89355149e80
-- name: github.com/lightninglabs/neutrino
-  version: 601b7eda6e5c9e8ca91c097f0bb7be2664802ab3
-  subpackages:
-  - filterdb
-  - headerfs
-- name: github.com/lightningnetwork/lightning-onion
-  version: 6d4b1353e2835def84ee240f40499464521c6046
-- name: github.com/ltcsuite/ltcd
-  version: 5f654d5faab99ee2b3488fabba98e5f7a5257ee3
-  subpackages:
-  - btcjson
-  - chaincfg
-  - chaincfg/chainhash
-  - wire
-- name: github.com/miekg/dns
-  version: 946bd9fbed05568b0f3cd188353d8aa28f38b688
-  subpackages:
-  - internal/socket
-- name: github.com/roasbeef/btcd
-  version: e6807bc4dd5ddbb95b4ab163f6dd61e4ad79463a
-  subpackages:
-  - addrmgr
-  - blockchain
-  - btcec
-  - btcjson
-  - chaincfg
-  - chaincfg/chainhash
-  - connmgr
-  - database
-  - integration/rpctest
-  - peer
-  - rpcclient
-  - txscript
-  - wire
-- name: github.com/roasbeef/btcrpcclient
-  version: d0f4db8b4dad0ca3d569b804f21247c3dd96acbb
-- name: github.com/roasbeef/btcutil
-  version: c3ff179366044979fb9856c2feb79bd4c2184c7a
-  subpackages:
-  - base58
-  - bech32
-  - bloom
-  - coinset
-  - gcs
-  - gcs/builder
-  - hdkeychain
-  - txsort
-- name: github.com/roasbeef/btcwallet
-  version: 46f7390abe89576059b52588d91b82212e753493
-  subpackages:
-  - chain
-  - internal/helpers
-  - internal/legacy/keystore
-  - internal/legacy/rename
-  - internal/prompt
-  - internal/zero
-  - snacl
-  - waddrmgr
-  - wallet
-  - wallet/internal/txsizes
-  - wallet/txauthor
-  - wallet/txrules
-  - walletdb
-  - walletdb/bdb
-  - wtxmgr
-- name: github.com/rogpeppe/fastuuid
-  version: 6724a57986aff9bff1a1770e9347036def7c89f6
-- name: github.com/tv42/zbase32
-  version: 501572607d0273fc75b3b261fa4904d63f6ffa0e
-- name: github.com/urfave/cli
-  version: cfb38830724cc34fedffe9a2a29fb54fa9169cd1
-- name: github.com/Yawning/aez
-  version: 4dad034d9db2caec23fb8f69b9160ae16f8d46a3
-- name: golang.org/x/crypto
-  version: 49796115aa4b964c318aad4f3084fdb41e9aa067
-  subpackages:
-  - blake2b
-  - chacha20poly1305
-  - curve25519
-  - hkdf
-  - internal/chacha20
-  - nacl/box
-  - nacl/secretbox
-  - pbkdf2
-  - poly1305
-  - ripemd160
-  - salsa20
-  - salsa20/salsa
-  - scrypt
-  - ssh/terminal
-- name: golang.org/x/net
-  version: 66aacef3dd8a676686c7ae3716979581e8b03c47
-  subpackages:
-  - context
-  - http2
-  - http2/hpack
-  - idna
-  - internal/timeseries
-  - lex/httplex
-  - proxy
-  - trace
-- name: golang.org/x/sys
-  version: ab9e364efd8b52800ff7ee48a9ffba4e0ed78dfb
-  subpackages:
-  - unix
-  - windows
-- name: golang.org/x/text
-  version: 18c65dde6afd36dbc39197ca72008895b8dfbfb6
-  subpackages:
-  - secure/bidirule
-  - transform
-  - unicode/bidi
-  - unicode/norm
-- name: google.golang.org/genproto
-  version: ee236bd376b077c7a89f260c026c4735b195e459
-  subpackages:
-  - googleapis/api/annotations
-  - googleapis/rpc/status
-- name: google.golang.org/grpc
-  version: b3ddf786825de56a4178401b7e174ee332173b66
-  subpackages:
-  - codes
-  - connectivity
-  - credentials
-  - grpclb/grpc_lb_v1
-  - grpclog
-  - internal
-  - keepalive
-  - metadata
-  - naming
-  - peer
-  - stats
-  - status
-  - tap
-  - transport
-- name: gopkg.in/errgo.v1
-  version: 442357a80af5c6bf9b6d51ae791a39c3421004f3
-- name: gopkg.in/macaroon-bakery.v2
-  version: 04cf5ef151a211d929975161aea7c65f94c90446
-  subpackages:
-  - bakery
-  - bakery/checkers
-  - bakery/internal/macaroonpb
-- name: gopkg.in/macaroon.v2
-  version: bed2a428da6e56d950bed5b41fcbae3141e5b0d0
-testImports: []
diff --git a/glide.yaml b/glide.yaml
deleted file mode 100644
index ae33fb1d4..000000000
--- a/glide.yaml
+++ /dev/null
@@ -1,87 +0,0 @@
-package: github.com/lightningnetwork/lnd
-import:
-- package: github.com/coreos/bbolt
-  version: 4f5275f4ebbf6fe7cb772de987fa96ee674460a7
-- package: github.com/btcsuite/btclog
-  version: 84c8d2346e9fc8c7b947e243b9c24e6df9fd206a
-- package: github.com/jessevdk/go-flags
-- package: github.com/jrick/logrotate
-  version: a93b200c26cbae3bb09dd0dc2c7c7fe1468a034a
-- package: github.com/davecgh/go-spew
-  subpackages:
-  - spew
-- package: github.com/golang/protobuf
-  subpackages:
-  - proto
-- package: github.com/howeyc/gopass
-- package: github.com/roasbeef/btcd
-  version: e6807bc4dd5ddbb95b4ab163f6dd61e4ad79463a
-  subpackages:
-  - blockchain
-  - btcec
-  - btcjson
-  - chaincfg
-  - txscript
-  - wire
-  - connmgr
-- package: github.com/lightninglabs/gozmq
-  version: 0d266ba6d55ea65c18c7a02d8992c89355149e80
-- package: github.com/roasbeef/btcrpcclient
-  version: d0f4db8b4dad0ca3d569b804f21247c3dd96acbb
-- package: github.com/roasbeef/btcutil
-  version: c3ff179366044979fb9856c2feb79bd4c2184c7a
-  subpackages:
-  - bloom
-  - coinset
-  - hdkeychain
-  - txsort
-- package: github.com/roasbeef/btcwallet
-  version: 46f7390abe89576059b52588d91b82212e753493
-  subpackages:
-  - chain
-  - waddrmgr
-  - wallet
-  - walletdb/bdb
-- package: github.com/urfave/cli
-  version: ^1.18.0
-- package: golang.org/x/crypto
-  version: 49796115aa4b964c318aad4f3084fdb41e9aa067
-  subpackages:
-  - hkdf
-  - nacl/secretbox
-  - ripemd160
-  - scrypt
-  - chacha20poly1305
-  - salsa20
-- package: golang.org/x/net
-  subpackages:
-  - context
-- package: google.golang.org/grpc
-  version: b3ddf786825de56a4178401b7e174ee332173b66
-- package: github.com/lightningnetwork/lightning-onion
-  version: 6d4b1353e2835def84ee240f40499464521c6046
-- package: github.com/grpc-ecosystem/grpc-gateway
-  version: f2862b476edcef83412c7af8687c9cd8e4097c0f
-- package: github.com/go-errors/errors
-- package: github.com/tv42/zbase32
-- package: github.com/awalterschulze/gographviz
-  version: ^1.0.0
-- package: google.golang.org/genproto
-  subpackages:
-  - googleapis/api/annotations
-- package: github.com/ltcsuite/ltcd
-  version: 5f654d5faab99ee2b3488fabba98e5f7a5257ee3
-  subpackages:
-  - chaincfg
-- package: github.com/lightninglabs/neutrino
-  version: 601b7eda6e5c9e8ca91c097f0bb7be2664802ab3
-- package: gopkg.in/macaroon.v2
-- package: gopkg.in/macaroon-bakery.v2
-- package: github.com/juju/loggo
-- package: github.com/rogpeppe/fastuuid
-- package: gopkg.in/errgo.v1
-- package: github.com/miekg/dns
-- package: github.com/Yawning/aez
-  version: 4dad034d9db2caec23fb8f69b9160ae16f8d46a3
-- package: github.com/kkdai/bstream
-  version: f391b8402d23024e7c0f624b31267a89998fca95
diff --git a/gotest.sh b/gotest.sh
index 386b50ffa..a1d0b8b0e 100755
--- a/gotest.sh
+++ b/gotest.sh
@@ -93,7 +93,7 @@ lint_check() {
     gometalinter.v1 --install 1>/dev/null
 
     # Automatic checks
-    linter_targets=$(glide novendor | grep -v lnrpc)
+    linter_targets=$(go list -f '{{.Dir}}' ./... | grep -v lnrpc)
     test -z "$(gometalinter.v1 --disable-all \
     --enable=gofmt \
     --enable=vet \
@@ -134,17 +134,17 @@ while getopts "lrcio" flag; do
 # remove the options from the positional parameters
 shift $(( OPTIND - 1 ))
 
-# Make sure glide is installed and $GOPATH/bin is in your path.
-if [ ! -x "$(type -p glide)" ]; then
-    print "* Install glide"
-    go get -u github.com/Masterminds/glide
+# Make sure dep is installed and $GOPATH/bin is in your path.
+if [ ! -x "$(type -p dep)" ]; then
+    print "* Install dep"
+    go get -u github.com/golang/dep/cmd/dep
 fi
 
 # Install the dependency if vendor directory not exist or if flag have been
 # specified.
 if [ "$NEED_INSTALL" == "true" ] || [ ! -d "./vendor" ]; then
     print "* Install dependencies"
-    glide install
+    dep ensure
 fi
 
 # Required for the integration tests